@@ -304,6 +304,8 @@ class Line:
         return Target(self)
     
     def setVar(self, action, *items):
+        tags = actions[action.title()]['tags']
+
         formatted = []
 
         index = 0
@@ -320,6 +322,15 @@ class Line:
 
             index += 1
         
+        for tag in tags:
+            formatted.append({"item": {
+                "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
+                "action": action, "block": "player_action"}},
+                "slot": index
+            })
+
+            index -= 1
+        
         self.code['blocks'].append({"block": "set_var", "id": "block", "args": {
             "items": formatted
         }, "action": action})
@@ -342,6 +353,8 @@ class Line:
         return Close(self)
     
     def ifEntity(self, action, *items):
+        tags = actions[action.title()]['tags']
+
         formatted = []
 
         index = 0
@@ -358,6 +371,15 @@ class Line:
 
             index += 1
         
+        for tag in tags:
+            formatted.append({"item": {
+                "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
+                "action": action, "block": "player_action"}},
+                "slot": index
+            })
+
+            index -= 1
+        
         self.code['blocks'].append({"block": "if_entity", "id": "block", "args": {
             "items": formatted
         }, "action": action})
@@ -367,6 +389,8 @@ class Line:
         return Not(self)
     
     def ifGame(self, action, *items):
+        tags = actions[action.title()]['tags']
+
         formatted = []
 
         index = 0
@@ -383,6 +407,15 @@ class Line:
 
             index += 1
         
+        for tag in tags:
+            formatted.append({"item": {
+                "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
+                "action": action, "block": "player_action"}},
+                "slot": index
+            })
+
+            index -= 1
+        
         self.code['blocks'].append({"block": "if_game", "id": "block", "args": {
             "items": formatted
         }, "action": action})
@@ -392,6 +425,8 @@ class Line:
         return Not(self)
 
     def ifPlayer(self, action, *items):
+        tags = actions[action.title()]['tags']
+
         formatted = []
 
         index = 0
@@ -408,6 +443,15 @@ class Line:
 
             index += 1
         
+        for tag in tags:
+            formatted.append({"item": {
+                "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
+                "action": action, "block": "player_action"}},
+                "slot": index
+            })
+
+            index -= 1
+        
         self.code['blocks'].append({"block": "if_player", "id": "block", "args": {
             "items": formatted
         }, "action": action})
@@ -417,6 +461,11 @@ class Line:
         return Not(self)
 
     def ifVar(self, action, *items):
+        try:
+            tags = actions[action.title()]['tags']
+        except:
+            tags = []
+
         formatted = []
 
         index = 0
@@ -433,6 +482,15 @@ class Line:
 
             index += 1
         
+        for tag in tags:
+            formatted.append({"item": {
+                "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
+                "action": action, "block": "if_var"}},
+                "slot": index
+            })
+
+            index -= 1
+        
         self.code['blocks'].append({"block": "if_var", "id": "block", "args": {
             "items": formatted
         }, "action": action})
@@ -442,6 +500,11 @@ class Line:
         return Not(self)
     
     def repeat(self, action, *items):
+        try:
+            tags = actions[action.title()]['tags']
+        except:
+            tags = []
+
         formatted = []
 
         index = 0
@@ -458,6 +521,15 @@ class Line:
 
             index += 1
         
+        for tag in tags:
+            formatted.append({"item": {
+                "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
+                "action": action, "block": "repeat"}},
+                "slot": index
+            })
+
+            index -= 1
+        
         self.code['blocks'].append({"block": "repeat", "id": "block", "args": {
             "items": formatted
         }, "action": action})
